bayespy.inference.vmp.nodes.stochastic.Distribution.plates_from_parent
======================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.stochastic

.. automethod:: Distribution.plates_from_parent